### Name: candidateReduction
### Title: Ranks candidate variables for dimension reduction prior to
###   estimation selection with the DSA
### Aliases: candidateReduction
### Keywords: models,reduction

### ** Examples

library(DSA)

n <- 1000
W <- cbind(rnorm(n), rnorm(n) < 1, rnorm(n) < 2, rnorm(n, 2, 4), runif(n),
           rcauchy(n), rlogis(n) < .1, rnorm(n) < .1, rnorm(n, 120, 10),
           rnorm(n, 66, 2))

Y <- 10 + .5*W[,1] + .02*W[,1]^2 + .01*W[,1]*W[,2] + 2*W[,3] + .7*W[,4]^2 
Y <- as.matrix(as.integer(Y - mean(Y))/sd(Y))
trials <- rpois(n, lambda = 20)
successes <- sapply(1:n, function(i) {
  rbinom(1, size = trials[i], prob = pnorm(Y[i]))
})
failures <- trials - successes
colnames(W) <- paste("W", 1:ncol(W), sep = "")
data <- as.data.frame(cbind(W, "successes" = successes, "failures" = failures))

res <- candidateReduction(cbind(successes, failures) ~ ., data,family=binomial)  
res

res <- candidateReduction(W1 ~ ., as.data.frame(W),)  
res



